@@ -1,5 +1,5 @@
 #!/bin/sh
-# Copyright (C) 2014 Free Software Foundation, Inc.
+# Copyright (C) 2014-2023 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,4 +19,4 @@ srcdir=${srcdir:-.}
 
 # Look for a non-existent entry in INFOPATH.
 
-$GINFO --output - --file not-a-file 2>&1 | grep 'No such file or directory'
+$ginfo --output - --file not-a-file 2>&1 | grep 'No such file or directory'
