@@ -1,6 +1,6 @@
 /* terminal.c -- how to handle the physical terminal for Info.
 
-   Copyright 1988-2022 Free Software Foundation, Inc.
+   Copyright 1988-2023 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -53,32 +53,33 @@ extern int tputs ();
    function is called when appropriate instead of its namesake.  Your
    function is called with exactly the same arguments that were passed
    to the namesake function. */
-VFunction *terminal_begin_inverse_hook = NULL;
-VFunction *terminal_end_inverse_hook = NULL;
-VFunction *terminal_begin_standout_hook = NULL;
-VFunction *terminal_end_standout_hook = NULL;
-VFunction *terminal_begin_underline_hook = NULL;
-VFunction *terminal_end_underline_hook = NULL;
-VFunction *terminal_begin_bold_hook = NULL;
-VFunction *terminal_begin_blink_hook = NULL;
-VFunction *terminal_end_all_modes_hook = NULL;
-VFunction *terminal_default_colour_hook = NULL;
-VFunction *terminal_set_colour_hook = NULL;
-VFunction *terminal_set_bgcolour_hook = NULL;
-VFunction *terminal_prep_terminal_hook = NULL;
-VFunction *terminal_unprep_terminal_hook = NULL;
-VFunction *terminal_up_line_hook = NULL;
-VFunction *terminal_down_line_hook = NULL;
-VFunction *terminal_clear_screen_hook = NULL;
-VFunction *terminal_clear_to_eol_hook = NULL;
-VFunction *terminal_get_screen_size_hook = NULL;
-VFunction *terminal_goto_xy_hook = NULL;
-VFunction *terminal_initialize_terminal_hook = NULL;
-VFunction *terminal_new_terminal_hook = NULL;
-VFunction *terminal_put_text_hook = NULL;
-VFunction *terminal_ring_bell_hook = NULL;
-VFunction *terminal_write_chars_hook = NULL;
-VFunction *terminal_scroll_terminal_hook = NULL;
+
+void (*terminal_initialize_terminal_hook) (char *terminal_name) = NULL;
+void (*terminal_get_screen_size_hook) (void) = NULL;
+int (*terminal_prep_terminal_hook) (void) = NULL;
+void (*terminal_unprep_terminal_hook) (void) = NULL;
+void (*terminal_new_terminal_hook) (char *terminal_name) = NULL;
+void (*terminal_goto_xy_hook) (int x, int y) = NULL;
+void (*terminal_put_text_hook) (char *string) = NULL;
+void (*terminal_write_chars_hook) (char *string, int nchars) = NULL;
+void (*terminal_clear_to_eol_hook) (void) = NULL;
+void (*terminal_clear_screen_hook) (void) = NULL;
+void (*terminal_up_line_hook) (void) = NULL;
+void (*terminal_down_line_hook) (void) = NULL;
+void (*terminal_begin_inverse_hook) (void) = NULL;
+void (*terminal_end_inverse_hook) (void) = NULL;
+void (*terminal_begin_standout_hook) (void) = NULL;
+void (*terminal_end_standout_hook) (void) = NULL;
+void (*terminal_begin_underline_hook) (void) = NULL;
+void (*terminal_end_underline_hook) (void) = NULL;
+void (*terminal_scroll_terminal_hook) (int start, int end, int amount) = NULL;
+void (*terminal_ring_bell_hook) (void) = NULL;
+void (*terminal_begin_bold_hook) (void) = NULL;
+void (*terminal_begin_blink_hook) (void) = NULL;
+void (*terminal_default_colour_hook) (void) = NULL;
+void (*terminal_set_colour_hook) (int) = NULL;
+void (*terminal_set_bgcolour_hook) (int) = NULL;
+void (*terminal_end_all_modes_hook) (void) = NULL;
 
 /* User variable 'mouse'.  Values can be MP_* constants in terminal.h. */
 int mouse_protocol = MP_NONE;
@@ -123,9 +124,6 @@ static char *term_invbeg;
 /* The string to turn off inverse mode, if this term has one. */
 static char *term_invend;
 
-/* String introducing a mouse event. */
-static char *term_Km;
-
 /* Strings entering and leaving standout mode. */
 char *term_so, *term_se;
 
@@ -173,14 +171,12 @@ terminal_begin_using_terminal (void)
   void (*sigsave) (int signum);
 
   /* Turn on mouse reporting.  This is "normal tracking mode" supported by
-     xterm.  The presence of the Km capability may not be a reliable way to
-     tell whether this mode exists, but sending the following sequence is
-     probably harmless if it doesn't.  */
-  if (mouse_protocol == MP_NORMAL_TRACKING
-      && term_Km && !strcmp (term_Km, "\033[M"))
+     xterm.
+     We used to check the presence of the Km (kmous) termcap capability, but
+     it may be set to different values (either "\033[M" or "\033[<") for
+     xterm, so we cannot rely on the value of this capability. */
+  if (mouse_protocol == MP_NORMAL_TRACKING)
     send_to_terminal ("\033[?1000h");
-  else
-    term_Km = 0;
 
   if (term_keypad_on)
       send_to_terminal (term_keypad_on);
@@ -214,7 +210,7 @@ terminal_end_using_terminal (void)
   void (*sigsave) (int signum);
 
   /* Turn off mouse reporting ("normal tracking mode"). */
-  if (term_Km)
+  if (mouse_protocol == MP_NORMAL_TRACKING)
     send_to_terminal ("\033[?1000l");
 
   if (term_keypad_off)
@@ -880,8 +876,8 @@ initialize_byte_map (void)
       add_seq_to_byte_map (keys2[i].key_id, keys2[i].byte_seq);
     }
 
-  if (term_Km)
-    add_seq_to_byte_map (KEY_MOUSE, term_Km);
+  /* In case "normal tracking mode" is on. */
+  add_seq_to_byte_map (KEY_MOUSE, "\033[M");
 
   /* Special case for ESC: Can introduce special key sequences, represent the
      Meta key being pressed, or be a key on its own. */
@@ -1040,9 +1036,6 @@ terminal_initialize_terminal (char *terminal_name)
 
   term_kB = tgetstr ("kB", &buffer);
 
-  /* String introducing a mouse event. */
-  term_Km = tgetstr ("Km", &buffer);
-
   initialize_byte_map ();
 
   /* If this terminal is not cursor addressable, then it is really dumb. */
