@@ -1,13 +1,16 @@
 char *xs_unicode_text (char *, int);
 char *xs_entity_text (char *);
 char *xs_process_text (char *text);
-HV *xs_merge_text (HV *self, HV *current, SV *text_in);
-int xs_abort_empty_line (HV *self, HV *current, SV *additional_text);
+void xs_parse_command_name (SV *text,
+                            char **,
+                            int*);
 void xs_parse_texi_regex (SV *text,
                           char **,
                           char **,
                           char **,
                           char **,
                           char **,
+                          char **,
+                          char **,
                           char **);
 char *xs_default_format_protect_text (char *);
