@@ -17,9 +17,11 @@ $result_trees{'enumerate_in_example'} = {
         {
           'args' => [
             {
-              'extra' => {
-                'spaces_after_argument' => '
+              'info' => {
+                'spaces_after_argument' => {
+                  'text' => '
 '
+                }
               },
               'type' => 'block_line_arg'
             }
@@ -29,9 +31,11 @@ $result_trees{'enumerate_in_example'} = {
             {
               'args' => [
                 {
-                  'extra' => {
-                    'spaces_after_argument' => '
+                  'info' => {
+                    'spaces_after_argument' => {
+                      'text' => '
 '
+                    }
                   },
                   'type' => 'block_line_arg'
                 }
@@ -107,18 +111,24 @@ $result_trees{'enumerate_in_example'} = {
                           'text' => 'enumerate'
                         }
                       ],
-                      'extra' => {
-                        'spaces_after_argument' => '
+                      'info' => {
+                        'spaces_after_argument' => {
+                          'text' => '
 '
+                        }
                       },
                       'type' => 'line_arg'
                     }
                   ],
                   'cmdname' => 'end',
                   'extra' => {
-                    'spaces_before_argument' => ' ',
                     'text_arg' => 'enumerate'
                   },
+                  'info' => {
+                    'spaces_before_argument' => {
+                      'text' => ' '
+                    }
+                  },
                   'source_info' => {
                     'file_name' => '',
                     'line_nr' => 8,
@@ -143,18 +153,24 @@ $result_trees{'enumerate_in_example'} = {
                       'text' => 'example'
                     }
                   ],
-                  'extra' => {
-                    'spaces_after_argument' => '
+                  'info' => {
+                    'spaces_after_argument' => {
+                      'text' => '
 '
+                    }
                   },
                   'type' => 'line_arg'
                 }
               ],
               'cmdname' => 'end',
               'extra' => {
-                'spaces_before_argument' => ' ',
                 'text_arg' => 'example'
               },
+              'info' => {
+                'spaces_before_argument' => {
+                  'text' => ' '
+                }
+              },
               'source_info' => {
                 'file_name' => '',
                 'line_nr' => 9,
@@ -220,6 +236,18 @@ still second
 ';
 
 
+$result_converted{'xml'}->{'enumerate_in_example'} = '
+<example endspaces=" ">
+<enumerate first="1" endspaces=" ">
+<listitem><pre xml:space="preserve"> first item
+</pre></listitem><listitem><pre xml:space="preserve"> second  item
+
+still second
+</pre></listitem></enumerate>
+</example>
+';
+
+
 $result_converted{'latex_text'}->{'enumerate_in_example'} = '
 \\begin{Texinfoindented}
 \\begin{enumerate}[start=1]
